@@ -16,6 +16,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+#include <cstdio>
 
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/debug/logstream.hxx>
@@ -32,28 +33,39 @@
 #include "AIScenario.hxx"
 #include "AIFlightPlan.hxx"
 
-
+static list<string>
+getAllNodeVals(const char* name, SGPropertyNode * entry_node);
 
 FGAIScenario::FGAIScenario(string &filename)
 {
   int i;
   SGPath path( globals->get_fg_root() );
+  
+//   cout << "/Data/AI/" << filename << endl;
+  
   path.append( ("/Data/AI/" + filename + ".xml").c_str() );
   SGPropertyNode root;
-
+  readProperties(path.str(), &root);
+  
+//   cout <<"path " << path.str() << endl;
+  
   try {
       readProperties(path.str(), &root);
   } catch (const sg_exception &e) {
       SG_LOG(SG_GENERAL, SG_ALERT,
        "Incorrect path specified for AI scenario: ");
+       
        cout << path.str() << endl;
+      
       return;
   }
 
   entries.clear();
   SGPropertyNode * node = root.getNode("scenario");
   for (i = 0; i < node->nChildren(); i++) { 
-     //cout << "Reading entry " << i << endl;        
+     
+//      cout << "Reading entity data entry " << i << endl;        
+     
      SGPropertyNode * entry_node = node->getChild(i);
 
      FGAIModelEntity* en = new FGAIModelEntity;
@@ -74,15 +86,23 @@ FGAIScenario::FGAIScenario(string &filename)
      en->rudder         = entry_node->getDoubleValue("rudder", 0.0);
      en->strength       = entry_node->getDoubleValue("strength-fps", 0.0);
      en->diameter       = entry_node->getDoubleValue("diameter-ft", 0.0);
+     en->height_msl     = entry_node->getDoubleValue("height-msl", 5000.0);
      en->eda            = entry_node->getDoubleValue("eda", 0.007);
      en->life           = entry_node->getDoubleValue("life", 900.0);
      en->buoyancy       = entry_node->getDoubleValue("buoyancy", 0);
      en->wind_from_east = entry_node->getDoubleValue("wind_from_east", 0);
      en->wind_from_north = entry_node->getDoubleValue("wind_from_north", 0);
-     en->wind            = entry_node->getBoolValue("wind", false);
-     en->cd              = entry_node->getDoubleValue  ("cd", 0.029); 
-     en->mass            = entry_node->getDoubleValue  ("mass", 0.007); 
-
+     en->wind            = entry_node->getBoolValue  ("wind", false);
+     en->cd              = entry_node->getDoubleValue("cd", 0.029); 
+     en->mass            = entry_node->getDoubleValue("mass", 0.007); 
+     en->radius          = entry_node->getDoubleValue("turn-radius-ft", 2000);
+     en->x_offset        = entry_node->getDoubleValue("x-offset-m", 5.5); 
+     en->y_offset        = entry_node->getDoubleValue("y-offset-m", 1.0); 
+     en->z_offset        = entry_node->getDoubleValue("z-offset-m", 1.0); 
+ /*  en->name            = entry_node->getStringValue("name", "");*/
+     en->wire_objects     = getAllNodeVals("wire", entry_node);
+     en->catapult_objects = getAllNodeVals("catapult", entry_node);
+     en->solid_objects    = getAllNodeVals("solid", entry_node);
 
      en->fp             = NULL;
      if (en->flightplan != ""){
@@ -118,5 +138,25 @@ int FGAIScenario::nEntries( void )
   return entries.size();
 }
 
+static list<string>
+getAllNodeVals(const char* name, SGPropertyNode * entry_node)
+{
+  list<string> retval;
+  int i=0;
+  do {
+    char nodename[100];
+    snprintf(nodename, sizeof(nodename), "%s[%d]", name, i);
+    const char* objname = entry_node->getStringValue(nodename, 0);
+    if (objname == 0)
+      return retval;
+
+    retval.push_back(string(objname));
+    ++i;
+  } while (1);
+
+  return retval;
+}
+
+
 // end scenario.cxx
 
