@@ -86,8 +86,8 @@ void FGATCMgr::unbind() {
 void FGATCMgr::init() {
 	//cout << "ATCMgr::init called..." << endl;
 	
-	comm_node[0] = fgGetNode("/radios/comm[0]/frequencies/selected-mhz", true);
-	comm_node[1] = fgGetNode("/radios/comm[1]/frequencies/selected-mhz", true);
+	comm_node[0] = fgGetNode("/instrumentation/comm[0]/frequencies/selected-mhz", true);
+	comm_node[1] = fgGetNode("/instrumentation/comm[1]/frequencies/selected-mhz", true);
 	lon_node = fgGetNode("/position/longitude-deg", true);
 	lat_node = fgGetNode("/position/latitude-deg", true);
 	elev_node = fgGetNode("/position/altitude-ft", true);
@@ -221,9 +221,9 @@ bool FGATCMgr::AIRegisterAirport(string ident) {
 			//cout << "ident = " << ident << '\n';
 			AirportATC *a = new AirportATC;
 			// I'm not entirely sure that this AirportATC structure business is actually needed - it just duplicates what we can find out anyway!
-			a->lon = ap.longitude;
-			a->lat = ap.latitude;
-			a->elev = ap.elevation;
+			a->lon = ap._longitude;
+			a->lat = ap._latitude;
+			a->elev = ap._elevation;
 			a->atis_freq = GetFrequency(ident, ATIS);
 			//cout << "ATIS freq = " << a->atis_freq << '\n';
 			a->atis_active = false;
@@ -270,9 +270,9 @@ bool FGATCMgr::CommRegisterAirport(string ident, int chan, atc_type tp) {
 		if(dclFindAirportID(ident, &ap)) {
 			AirportATC *a = new AirportATC;
 			// I'm not entirely sure that this AirportATC structure business is actually needed - it just duplicates what we can find out anyway!
-			a->lon = ap.longitude;
-			a->lat = ap.latitude;
-			a->elev = ap.elevation;
+			a->lon = ap._longitude;
+			a->lat = ap._latitude;
+			a->elev = ap._elevation;
 			a->atis_freq = GetFrequency(ident, ATIS);
 			a->atis_active = false;
 			a->tower_freq = GetFrequency(ident, TOWER);
