@@ -1,7 +1,7 @@
 // auto_gui.cxx -- autopilot gui interface
 //
 // Written by Norman Vine <nhv@cape.com>
-// Arranged by Curt Olson <curt@flightgear.org>
+// Arranged by Curt Olson <http://www.flightgear.org/~curt>
 //
 // Copyright (C) 1998 - 2000
 //
@@ -19,7 +19,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: auto_gui.cxx,v 1.9 2004/05/26 18:15:19 curt Exp $
+// $Id: auto_gui.cxx,v 1.11 2004/12/22 23:57:08 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -668,7 +668,7 @@ int NewWaypoint( string Tgt_Alt )
 
       sprintf( NewTgtAirportId, "%s", TgtAptId.c_str() );
 
-      SGWayPoint wp( a.longitude, a.latitude, alt,
+      SGWayPoint wp( a._longitude, a._latitude, alt,
                      SGWayPoint::WGS84, TgtAptId );
       rm->add_waypoint( wp );
 
