@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: cockpit.cxx,v 1.10 2004/06/14 16:38:44 curt Exp $
+// $Id: cockpit.cxx,v 1.13 2004/12/19 14:32:39 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -29,7 +29,9 @@
 #  include <windows.h>
 #endif
 
-#include <GL/glu.h>
+#include <simgear/compiler.h>
+
+#include SG_GLU_H
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -43,7 +45,9 @@
 
 #include <Aircraft/aircraft.hxx>
 #include <Include/general.hxx>
-#include <FDM/ADA.hxx>
+#ifdef ENABLE_SP_FMDS
+#include <FDM/SP/ADA.hxx>
+#endif
 #include <Main/globals.hxx>
 #include <Main/fg_props.hxx>
 #include <Main/viewmgr.hxx>
@@ -282,7 +286,7 @@ float get_view_direction( void )
 float get_dme( void )
 {
     static const SGPropertyNode * dme_node =
-        fgGetNode("/radios/dme/distance-nm");
+        fgGetNode("/instrumentation/dme/indicated-distance-nm");
 
     return dme_node->getFloatValue();
 }
@@ -337,6 +341,7 @@ float get_anzg   ( void )
     return anzg;
 }
 
+#ifdef ENABLE_SP_FMDS
 int get_iaux1 (void)
 {
     FGADA *fdm = (FGADA *)current_aircraft.fdm_state;
@@ -516,7 +521,7 @@ float get_aux18 (void)
     FGADA *fdm = (FGADA *)current_aircraft.fdm_state;
     return fdm->get_faux(10);
 }
-// #endif
+#endif
 // $$$ end - added, VS Renganathan 13 Oct 2K
 
 
