@@ -16,7 +16,7 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//  $Id: panel.cxx,v 1.33 2004/09/20 13:21:51 ehofman Exp $
+//  $Id: panel.cxx,v 1.34 2004/11/18 19:53:00 curt Exp $
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -29,7 +29,9 @@
 #include <stdio.h>	// sprintf
 #include <string.h>
 
-#include <GL/glu.h>
+#include <simgear/compiler.h>
+
+#include SG_GLU_H
 
 #include <plib/ssg.h>
 #include <plib/fnt.h>
