@@ -59,7 +59,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_FCS "$Id: FGFCS.h,v 1.8 2004/09/11 12:41:05 ehofman Exp $"
+#define ID_FCS "$Id: FGFCS.h,v 1.9 2004/12/16 12:47:20 ehofman Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -134,7 +134,7 @@ CLASS DOCUMENTATION
     In this case, the FCS would be read in from another file.
 
     @author Jon S. Berndt
-    @version $Id: FGFCS.h,v 1.8 2004/09/11 12:41:05 ehofman Exp $
+    @version $Id: FGFCS.h,v 1.9 2004/12/16 12:47:20 ehofman Exp $
     @see FGFCSComponent
     @see FGConfigFile
     @see FGGain
@@ -425,11 +425,16 @@ public:
       @return pointer to the State object */
   inline FGState* GetState(void) { return State; }
 
-  /** Retrieves all component names for inclusion in output stream */
-  string GetComponentStrings(void);
+  /** Retrieves all component names for inclusion in output stream
+      @param delimeter either a tab or comma string depending on output type
+      @return a string containing the descriptive names for all components */
+  string GetComponentStrings(string delimeter);
 
-  /** Retrieves all component outputs for inclusion in output stream */
-  string GetComponentValues(void);
+  /** Retrieves all component outputs for inclusion in output stream
+      @param delimeter either a tab or comma string depending on output type
+      @return a string containing the numeric values for the current set of
+      component outputs */
+  string GetComponentValues(string delimeter);
 
   /// @name Pilot input command setting
   //@{
