@@ -54,7 +54,7 @@ INCLUDES
 #include "FGLGear.h"
 #include "FGColumnVector3.h"
 
-#define ID_GROUNDREACTIONS "$Id: FGGroundReactions.h,v 1.5 2004/03/14 14:57:07 ehofman Exp $"
+#define ID_GROUNDREACTIONS "$Id: FGGroundReactions.h,v 1.6 2004/12/16 12:47:20 ehofman Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -85,8 +85,8 @@ public:
   double GetForces(int idx) const {return vForces(idx);}
   FGColumnVector3& GetMoments(void) {return vMoments;}
   double GetMoments(int idx) const {return vMoments(idx);}
-  string GetGroundReactionStrings(void);
-  string GetGroundReactionValues(void);
+  string GetGroundReactionStrings(string delimeter);
+  string GetGroundReactionValues(string delimeter);
   
   inline int GetNumGearUnits(void) const { return lGear.size(); }
 
