@@ -41,7 +41,7 @@ INCLUDES
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGFCSComponent.cpp,v 1.7 2004/01/14 22:09:41 curt Exp $";
+static const char *IdSrc = "$Id: FGFCSComponent.cpp,v 1.8 2004/12/16 12:47:20 ehofman Exp $";
 static const char *IdHdr = ID_FCSCOMPONENT;
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -89,7 +89,7 @@ FGPropertyManager* FGFCSComponent::resolveSymbol(string token)
   FGPropertyManager* tmp = PropertyManager->GetNode(token,false);
   if (!tmp) {
     if (token.find("/") == token.npos) prop = "model/" + token;
-    cerr << "Creating new property " << prop << endl;
+    //cerr << "Creating new property " << prop << endl;
     tmp = PropertyManager->GetNode(token,true);
   }
   return tmp;  
