@@ -44,8 +44,12 @@
 	
 	CURRENT RCS HEADER:
 
-$Header: /var/cvs/FlightGear-0.9/FlightGear/src/FDM/LaRCsim/ls_matrix.c,v 1.1.1.1 2002/09/10 01:14:02 curt Exp $
+$Header: /var/cvs/FlightGear-0.9/source/src/FDM/LaRCsim/ls_matrix.c,v 1.2 2004/04/01 15:27:55 curt Exp $
 $Log: ls_matrix.c,v $
+Revision 1.2  2004/04/01 15:27:55  curt
+Clean up various compiler warnings that have crept into the code.  This
+by no means get's them all, but it's a start.
+
 Revision 1.1.1.1  2002/09/10 01:14:02  curt
 Initial revision of FlightGear-0.9.0
 
@@ -102,7 +106,7 @@ Initial revision.
 
 #define SWAP(a,b) {temp=(a);(a)=(b);(b)=temp;}
 
-static char rcsid[] = "$Id: ls_matrix.c,v 1.1.1.1 2002/09/10 01:14:02 curt Exp $";
+static char rcsid[] = "$Id: ls_matrix.c,v 1.2 2004/04/01 15:27:55 curt Exp $";
 
 
 int *nr_ivector(long nl, long nh)
@@ -176,7 +180,7 @@ int nr_gaussj(double **a, int n, double **b, int m)
 
 {
     int		*indxc, *indxr, *ipiv;
-    int 	i, icol, irow, j, k, l, ll;
+    int 	i, icol = 0, irow = 0, j, k, l, ll;
     double       big, dum, pivinv, temp;
 
     int		bexists = ((m != 0) || (b == 0));
