@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gui.h,v 1.9 2004/04/30 08:44:35 ehofman Exp $
+ * $Id: gui.h,v 1.11 2004/10/06 03:29:14 curt Exp $
  **************************************************************************/
 
 
@@ -57,9 +57,10 @@ extern int gui_menu_on;
 extern void saveFlight(puObject *);
 extern void loadFlight(puObject *);
 extern void reInit(puObject *);
-extern void dumpSnapShot(puObject *);
+extern void fgDumpSnapShotWrapper(puObject *);
 #ifdef TR_HIRES_SNAP
-extern void dumpHiResSnapShot(puObject *);
+extern void fgHiResDumpWrapper(puObject *);
+extern void fgHiResDump();
 #endif
 #if defined( WIN32 ) && !defined( __CYGWIN__) && !defined(__MINGW32__)
 extern void printScreen(puObject *);
