@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gui_funcs.cxx,v 1.26 2004/10/06 03:29:14 curt Exp $
+ * $Id: gui_funcs.cxx,v 1.28 2004/12/29 20:38:17 curt Exp $
  **************************************************************************/
 
 
@@ -40,7 +40,7 @@
 #  include <windows.h>
 #endif
 
-#include <GL/gl.h>
+#include SG_GL_H
 
 #if defined(FX) && defined(XMESA)
 #  include <GL/xmesa.h>
@@ -385,9 +385,6 @@ void goodBye(puObject *)
     //      "Program exiting normally at user request." );
     cout << "Program exiting normally at user request." << endl;
 
-    // close all external I/O connections
-    globals->get_io()->shutdown_all();
-
     exit(0);
 }
 
