@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: input.cxx,v 1.49 2004/06/24 02:08:38 david Exp $
+// $Id: input.cxx,v 1.55 2005/01/17 10:48:35 ehofman Exp $
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -474,11 +474,20 @@ FGInput::_init_joystick ()
     for (j = 0; j < (int)nb_axes; j++) {
       const SGPropertyNode * axis_node = axes[j];
       const SGPropertyNode * num_node = axis_node->getChild("number");
-      size_t n_axis = axis_node->getIndex();
+      int n_axis = axis_node->getIndex();
       if (num_node != 0) {
-          n_axis = num_node->getIntValue(TGT_PLATFORM,n_axis);
+          n_axis = num_node->getIntValue(TGT_PLATFORM, -1);
+
+          // Silently ignore platforms that are not specified within the
+          // <number></number> section
+          if (n_axis < 0)
+             continue;
       }
 
+      if (n_axis >= (size_t)naxes) {
+          SG_LOG(SG_INPUT, SG_DEBUG, "Dropping bindings for axis " << n_axis);
+          continue;
+      }
       axis &a = _joystick_bindings[i].axes[n_axis];
 
       js->setDeadBand(n_axis, axis_node->getDoubleValue("dead-band", 0.0));
@@ -512,6 +521,12 @@ FGInput::_init_joystick ()
       if (num_node != 0) {
           n_but = num_node->getIntValue(TGT_PLATFORM,n_but);
       }
+
+      if (n_but >= (size_t)nbuttons) {
+          SG_LOG(SG_INPUT, SG_DEBUG, "Dropping bindings for button " << n_but);
+          continue;
+      }
+
       sprintf(buf, "%d", n_but);
       SG_LOG(SG_INPUT, SG_DEBUG, "Initializing button " << n_but);
       _init_button(button_node,
@@ -541,7 +556,7 @@ FGInput::_init_joystick ()
 // cursors defined as textures referenced in the property tree.  This
 // list could then be eliminated. -Andy
 //
-struct {
+static struct {
   const char * name;
   int cursor;
 } mouse_cursor_map[] = {
