@@ -3,6 +3,11 @@
 //
 // This file is in the Public Domain and comes with no warranty.
 
+#include <simgear/compiler.h>
+#include STL_IOSTREAM
+#include STL_STRING
+#include <sstream>
+
 #include "turn_indicator.hxx"
 #include <Main/fg_props.hxx>
 #include <Main/util.hxx>
@@ -13,6 +18,29 @@
 #define RESPONSIVENESS 0.5
 
 
+TurnIndicator::TurnIndicator ( SGPropertyNode *node) :
+    _last_rate(0),
+    name("turn-indicator"),
+    num(0)
+{
+    int i;
+    for ( i = 0; i < node->nChildren(); ++i ) {
+        SGPropertyNode *child = node->getChild(i);
+        string cname = child->getName();
+        string cval = child->getStringValue();
+        if ( cname == "name" ) {
+            name = cval;
+        } else if ( cname == "number" ) {
+            num = child->getIntValue();
+        } else {
+            SG_LOG( SG_INSTR, SG_WARN, "Error in turn-indicator config logic" );
+            if ( name.length() ) {
+                SG_LOG( SG_INSTR, SG_WARN, "Section = " << name );
+            }
+        }
+    }
+}
+
 TurnIndicator::TurnIndicator () :
     _last_rate(0)
 {
@@ -25,28 +53,41 @@ TurnIndicator::~TurnIndicator ()
 void
 TurnIndicator::init ()
 {
+    string branch;
+    branch = "/instrumentation/" + name;
+
+    SGPropertyNode *node = fgGetNode(branch.c_str(), num, true );
     _roll_rate_node = fgGetNode("/orientation/roll-rate-degps", true);
     _yaw_rate_node = fgGetNode("/orientation/yaw-rate-degps", true);
     _electric_current_node = 
         fgGetNode("/systems/electrical/outputs/turn-coordinator", true);
-    _rate_out_node = 
-        fgGetNode("/instrumentation/turn-indicator/indicated-turn-rate", true);
+    _rate_out_node = node->getChild("indicated-turn-rate", 0, true);
 }
 
 void
 TurnIndicator::bind ()
 {
-    fgTie("/instrumentation/turn-indicator/serviceable",
+    std::ostringstream temp;
+    string branch;
+    temp << num;
+    branch = "/instrumentation/" + name + "[" + temp.str() + "]";
+
+    fgTie((branch + "/serviceable").c_str(),
           &_gyro, &Gyro::is_serviceable, &Gyro::set_serviceable);
-    fgTie("/instrumentation/turn-indicator/spin",
+    fgTie((branch + "/spin").c_str(),
           &_gyro, &Gyro::get_spin_norm, &Gyro::set_spin_norm);
 }
 
 void
 TurnIndicator::unbind ()
 {
-    fgUntie("/instrumentation/turn-indicator/serviceable");
-    fgUntie("/instrumentation/turn-indicator/spin");
+    std::ostringstream temp;
+    string branch;
+    temp << num;
+    branch = "/instrumentation/" + name + "[" + temp.str() + "]";
+
+    fgUntie((branch + "/serviceable").c_str());
+    fgUntie((branch + "/serviceable").c_str());
 }
 
 void
