@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: fg_props.cxx,v 1.19 2004/04/24 19:28:12 curt Exp $
+// $Id: fg_props.cxx,v 1.20 2004/10/24 11:05:14 ehofman Exp $
 
 #ifdef HAVE_CONFIG_H
 #  include <simgear/compiler.h>
@@ -82,6 +82,8 @@ LogClassMapping log_class_mappings [] = {
   LogClassMapping(SG_IO, "io"),
   LogClassMapping(SG_CLIPPER, "clipper"),
   LogClassMapping(SG_NETWORK, "network"),
+  LogClassMapping(SG_INSTR, "instrumentation"),
+  LogClassMapping(SG_SYSTEMS, "systems"),
   LogClassMapping(SG_UNDEFD, "")
 };
 
