@@ -2,7 +2,7 @@
 //
 // Written by Curtis Olson, started May 1997.
 //
-// Copyright (C) 1997 - 2002  Curtis L. Olson  - curt@flightgear.org
+// Copyright (C) 1997 - 2002  Curtis L. Olson  - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: main.cxx,v 1.183 2004/09/20 13:21:52 ehofman Exp $
+// $Id: main.cxx,v 1.193 2005/01/05 05:45:38 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -59,16 +59,17 @@
 
 #include <Include/general.hxx>
 #include <Cockpit/cockpit.hxx>
-#include <Cockpit/radiostack.hxx>
 #include <Cockpit/hud.hxx>
 #include <Model/panelnode.hxx>
 #include <Model/modelmgr.hxx>
 #include <Model/acmodel.hxx>
 #include <Scenery/scenery.hxx>
 #include <Scenery/tilemgr.hxx>
+#include <Sound/beacon.hxx>
+#include <Sound/morse.hxx>
 #include <FDM/flight.hxx>
 #include <FDM/UIUCModel/uiuc_aircraftdir.h>
-#include <FDM/ADA.hxx>
+// #include <FDM/ADA.hxx>
 #include <ATC/ATCdisplay.hxx>
 #include <ATC/ATCmgr.hxx>
 #include <ATC/AIMgr.hxx>
@@ -95,6 +96,7 @@
 
 static double real_delta_time_sec = 0.0;
 double delta_time_sec = 0.0;
+extern float init_volume;
 
 
 #ifdef macintosh
@@ -110,7 +112,6 @@ FGGeneral general;
 int idle_state = 0;
 long global_multi_loop;
 
-
 SGTimeStamp last_time_stamp;
 SGTimeStamp current_time_stamp;
 
@@ -126,8 +127,8 @@ extern int _bootstrap_OSInit;
 void fgUpdateTimeDepCalcs() {
     static bool inited = false;
 
-    static const SGPropertyNode *replay_master
-        = fgGetNode( "/sim/freeze/replay", true );
+    static const SGPropertyNode *replay_state
+        = fgGetNode( "/sim/freeze/replay-state", true );
     static SGPropertyNode *replay_time
         = fgGetNode( "/sim/replay/time", true );
     // static const SGPropertyNode *replay_end_time
@@ -161,15 +162,21 @@ void fgUpdateTimeDepCalcs() {
             inited = true;
         }
 
-        if ( ! replay_master->getBoolValue() ) {
+        if ( replay_state->getIntValue() == 0 ) {
+	    // replay off, run fdm
             cur_fdm_state->update( delta_time_sec );
         } else {
             FGReplay *r = (FGReplay *)(globals->get_subsystem( "replay" ));
             r->replay( replay_time->getDoubleValue() );
-            replay_time->setDoubleValue( replay_time->getDoubleValue()
-                                         + ( delta_time_sec
-                                             * fgGetInt("/sim/speed-up") ) );
-        }
+  	    if ( replay_state->getIntValue() == 1 ) {
+                // normal playback
+                replay_time->setDoubleValue( replay_time->getDoubleValue()
+                                             + ( delta_time_sec
+                                               * fgGetInt("/sim/speed-up") ) );
+	    } else if ( replay_state->getIntValue() == 2 ) {
+	        // paused playback (don't advance replay time)
+	    }
+	}
     } else {
         // do nothing, fdm isn't inited yet
     }
@@ -185,8 +192,6 @@ void fgUpdateTimeDepCalcs() {
                                   globals->get_time_params()->getLst(),
                                   cur_fdm_state->get_Latitude() );
 
-    // Update radio stack model
-    current_radiostack->update(delta_time_sec);
 }
 
 
@@ -214,10 +219,8 @@ static void fgMainLoop( void ) {
         = fgGetNode("/sim/freeze/clock", true);
     static const SGPropertyNode *cur_time_override
         = fgGetNode("/sim/time/cur-time-override", true);
-    // static const SGPropertyNode *replay_master
-    //     = fgGetNode("/sim/freeze/replay", true);
 
-    SGCloudLayer::enable_bump_mapping = fgGetBool("/sim/rendering/bump-mapping",true);
+    SGCloudLayer::enable_bump_mapping = fgGetBool("/sim/rendering/bump-mapping");
 
     // Update the elapsed time.
     static bool first_time = true;
@@ -241,6 +244,18 @@ static void fgMainLoop( void ) {
 
     real_delta_time_sec
         = double(current_time_stamp - last_time_stamp) / 1000000.0;
+    // round the real time down to a multiple of 1/model-hz.
+    // this way all systems are updated the _same_ amount of dt.
+    {
+      static double rem = 0.0;
+      real_delta_time_sec += rem;
+      double hz = model_hz;
+      double nit = floor(real_delta_time_sec*hz);
+      rem = real_delta_time_sec - nit/hz;
+      real_delta_time_sec = nit/hz;
+    }
+
+
     if ( clock_freeze->getBoolValue() ) {
         delta_time_sec = 0;
     } else {
@@ -540,6 +555,8 @@ static void fgMainLoop( void ) {
 
     if (!scenery_loaded && globals->get_tile_mgr()->all_queues_empty() && cur_fdm_state->get_inited()) {
         fgSetBool("sim/sceneryloaded",true);
+        fgSetFloat("/sim/sound/volume", init_volume);
+        globals->get_soundmgr()->set_volume(init_volume);
     }
 
     if (fgGetBool("/sim/rendering/specular-highlight")) {
@@ -567,8 +584,6 @@ static void fgIdleFunction ( void ) {
     // printf("idle state == %d\n", idle_state);
 
     if ( idle_state == 0 ) {
-        fgSetBool("sim/initialised", false);
-
         // Initialize the splash screen right away
         if ( fgGetBool("/sim/startup/splash-screen") ) {
             fgSplashInit(fgGetString("/sim/startup/splash-texture"));
@@ -652,7 +667,6 @@ static void fgIdleFunction ( void ) {
     if ( idle_state == 1000 ) {
         // We've finished all our initialization steps, from now on we
         // run the main loop.
-        fgSetBool("sim/initialised",true);
         fgSetBool("sim/sceneryloaded",false);
 
         fgRegisterIdleHandler(fgMainLoop);
@@ -705,7 +719,7 @@ bool fgMainInit( int argc, char **argv ) {
     fgInitFGRoot(argc, argv);
 
     // Check for the correct base package version
-    static char required_version[] = "0.9.6";
+    static char required_version[] = "0.9.8";
     string base_version = fgBasePackageVersion();
     if ( !(base_version == required_version) ) {
         // tell the operator how to use this application
@@ -722,6 +736,8 @@ bool fgMainInit( int argc, char **argv ) {
         exit(-1);
     }
 
+    sgUseDisplayList = fgGetBool( "/sim/rendering/use-display-list", true );
+
     // Initialize the Aircraft directory to "" (UIUC)
     aircraft_dir = "";
 
@@ -742,9 +758,9 @@ bool fgMainInit( int argc, char **argv ) {
     _bootstrap_OSInit++;
 #endif
 
-    fgRegisterWindowResizeHandler( FGRenderer::resize );
-    fgRegisterIdleHandler( fgIdleFunction );
-    fgRegisterDrawHandler( FGRenderer::update );
+    fgRegisterWindowResizeHandler( &FGRenderer::resize );
+    fgRegisterIdleHandler( &fgIdleFunction );
+    fgRegisterDrawHandler( &FGRenderer::update );
 
 #ifdef FG_ENABLE_MULTIPASS_CLOUDS
     bool get_stencil_buffer = true;
@@ -938,13 +954,8 @@ bool fgMainInit( int argc, char **argv ) {
     // build our custom render states
     globals->get_renderer()->build_states();
 
-    try {
-        // pass control off to the master event handler
-        fgOSMainLoop();
-    } catch (...) {
-        SG_LOG( SG_ALL, SG_ALERT,
-            "Unknown exception in the main loop. Aborting..." );
-    }
+    // pass control off to the master event handler
+    fgOSMainLoop();
 
     // we never actually get here ... but to avoid compiler warnings,
     // etc.
