@@ -2,7 +2,7 @@
 //
 // Written by Curtis Olson, started April 1998.
 //
-// Copyright (C) 1998  Curtis L. Olson  - curt@me.umn.edu
+// Copyright (C) 1998  Curtis L. Olson  - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: options.cxx,v 1.61 2004/08/21 12:00:12 ehofman Exp $
+// $Id: options.cxx,v 1.66 2004/12/04 21:06:57 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -1089,8 +1089,8 @@ fgOptNAV1( const char * arg )
 {
     double radial, freq;
     if (parse_colon(arg, &radial, &freq))
-        fgSetDouble("/radios/nav[0]/radials/selected-deg", radial);
-    fgSetDouble("/radios/nav[0]/frequencies/selected-mhz", freq);
+        fgSetDouble("/instrumentation/nav[0]/radials/selected-deg", radial);
+    fgSetDouble("/instrumentation/nav[0]/frequencies/selected-mhz", freq);
     return FG_OPTIONS_OK;
 }
 
@@ -1099,8 +1099,8 @@ fgOptNAV2( const char * arg )
 {
     double radial, freq;
     if (parse_colon(arg, &radial, &freq))
-        fgSetDouble("/radios/nav[1]/radials/selected-deg", radial);
-    fgSetDouble("/radios/nav[1]/frequencies/selected-mhz", freq);
+        fgSetDouble("/instrumentation/nav[1]/radials/selected-deg", radial);
+    fgSetDouble("/instrumentation/nav[1]/frequencies/selected-mhz", freq);
     return FG_OPTIONS_OK;
 }
 
@@ -1121,11 +1121,11 @@ fgOptDME( const char *arg )
     if (opt == "nav1") {
         fgSetInt("/instrumentation/dme/switch-position", 1);
         fgSetString("/instrumentation/dme/frequencies/source",
-                    "/radios/nav[0]/frequencies/selected-mhz");
+                    "/instrumentation/nav[0]/frequencies/selected-mhz");
     } else if (opt == "nav2") {
         fgSetInt("/instrumentation/dme/switch-position", 3);
         fgSetString("/instrumentation/dme/frequencies/source",
-                    "/radios/nav[1]/frequencies/selected-mhz");
+                    "/instrumentation/nav[1]/frequencies/selected-mhz");
     } else {
         fgSetInt("/instrumentation/dme/switch-position", 2);
         fgSetString("/instrumentation/dme/frequencies/source",
@@ -1286,7 +1286,7 @@ struct OptionDesc {
     {"start-date-gmt",               true,  OPTION_FUNC,   "", false, "", fgOptStartDateGmt },
     {"hud-tris",                     false, OPTION_STRING, "/sim/hud/frame-stat-type", false, "tris", 0 },
     {"hud-culled",                   false, OPTION_STRING, "/sim/hud/frame-stat-type", false, "culled", 0 },
-    {"atc610x",                      true,  OPTION_CHANNEL, "", false, "dummy", 0 },
+    {"atcsim",                       true,  OPTION_CHANNEL, "", false, "dummy", 0 },
     {"atlas",                        true,  OPTION_CHANNEL, "", false, "", 0 },
     {"httpd",                        true,  OPTION_CHANNEL, "", false, "", 0 },
 #ifdef FG_JPEG_SERVER
@@ -1327,12 +1327,13 @@ struct OptionDesc {
     {"config",                       true,  OPTION_FUNC,   "", false, "", fgOptConfig },
     {"aircraft",                     true,  OPTION_STRING, "/sim/aircraft", false, "", 0 },
     {"failure",                      true,  OPTION_FUNC,   "", false, "", fgOptFailure },
-    {"com1",                         true,  OPTION_DOUBLE, "/radios/comm[0]/frequencies/selected-mhz", false, "", 0 },
-    {"com2",                         true,  OPTION_DOUBLE, "/radios/comm[1]/frequencies/selected-mhz", false, "", 0 },
+    {"com1",                         true,  OPTION_DOUBLE, "/instrumentation/comm[0]/frequencies/selected-mhz", false, "", 0 },
+    {"com2",                         true,  OPTION_DOUBLE, "/instrumentation/comm[1]/frequencies/selected-mhz", false, "", 0 },
     {"nav1",                         true,  OPTION_FUNC,   "", false, "", fgOptNAV1 },
     {"nav2",                         true,  OPTION_FUNC,   "", false, "", fgOptNAV2 },
     {"adf",                          true,  OPTION_FUNC,   "", false, "", fgOptADF },
     {"dme",                          true,  OPTION_FUNC,   "", false, "", fgOptDME },
+    {"min-status",                   true,  OPTION_STRING,  "/sim/aircraft-min-status", false, "all", 0 },
     {0}
 };
 
@@ -1683,9 +1684,26 @@ fgUsage (bool verbose)
 #endif
 }
 
+// A simple function to return an integer depending on the position
+// of the status string within the array in order to determine the hierarchy.
+unsigned int getNumMaturity(const char * str) 
+{
+  // changes should also be reflected in $FG_ROOT/data/options.xml & 
+  // $FG_ROOT/data/Translations/string-default.xml
+  const char levels[][20]= {"alpha","beta","early-production","production",0}; 
+
+  for (unsigned int i=0; i<(sizeof(levels)/sizeof(levels[0])-1);i++) 
+    if (strcmp(str,levels[i])==0)
+      return i;
+
+  return 0;
+};
+
+
 static void fgSearchAircraft(const SGPath &path, string_list &aircraft,
                              bool recursive)
-{
+{   
+   
    ulDirEnt* dire;
    ulDir *dirp = ulOpenDir(path.str().c_str());
    if (dirp == NULL) {
@@ -1720,29 +1738,57 @@ static void fgSearchAircraft(const SGPath &path, string_list &aircraft,
           }
 
           SGPropertyNode *desc = NULL;
+	  SGPropertyNode *status = NULL;
+	  
           SGPropertyNode *node = root.getNode("sim");
           if (node) {
              desc = node->getNode("description");
+	     // if a status tag is found, read it in
+	     if (node->hasValue("status"))
+	     	status = node->getNode("status");
           }
 
           char cstr[96];
+	  //additionally display status information where it is available
+          
           if (strlen(dire->d_name) <= 27) {
              snprintf(cstr, 96, "   %-27s  %s", dire->d_name,
-                      (desc) ? desc->getStringValue() : "" );
+                      (desc) ? desc->getStringValue() : "");
 
           } else {
              snprintf(cstr, 96, "   %-27s\n%32c%s", dire->d_name, ' ',
-                      (desc) ? desc->getStringValue() : "" );
+                      (desc) ? desc->getStringValue() : "");
           }
 
-          aircraft.push_back(cstr);
-      }
+	  SGPropertyNode * required_status
+                             = fgGetNode ("/sim/aircraft-min-status", true);
+	  
+	  // If the node holds the value "all", then there wasn't any status 
+	  // level specified, so we simply go ahead and output ALL aircraft
+	  if (strcmp(required_status->getStringValue(),"all")==0) {	   
+		  aircraft.push_back(cstr);
+		  }
+	  else
+	  {
+	  // If the node doesn't hold "all" as its value, then we are supposed
+	  // to show only aircraft meeting specific status (development status)
+          // requirements:
+ 
+     if (node->hasValue("status"))     {
+     	  //Compare (minimally) required status level with actual aircraft status:
+	   if (	getNumMaturity(status->getStringValue() ) >= 
+	  	getNumMaturity(required_status->getStringValue() ) )
+				  aircraft.push_back(cstr); }
+	  			  		  
+	  }
+      
+   
+   }
    }
 
    ulCloseDir(dirp);
 }
 
-
 /*
  * Search in the current directory, and in on directory deeper
  * for <aircraft>-set.xml configuration files and show the aircaft name
