@@ -2,7 +2,7 @@
 //
 // Written by Curtis Olson, started September 2001.
 //
-// Copyright (C) 2001  Curtis L. Olson - curt@flightgear.org
+// Copyright (C) 2001  Curtis L. Olson - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: native_fdm.cxx,v 1.22 2004/04/02 16:19:59 curt Exp $
+// $Id: native_fdm.cxx,v 1.25 2005/01/05 03:43:05 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -173,7 +173,9 @@ void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
         net->fuel_flow[i] = node->getDoubleValue( "fuel-flow-gph" );
         net->egt[i] = node->getDoubleValue( "egt-degf" );
         // cout << "egt = " << aero->EGT << endl;
+        net->cht[i] = node->getDoubleValue( "cht-degf" );
         net->mp_osi[i] = node->getDoubleValue( "mp-osi" );
+        net->tit[i] = node->getDoubleValue( "tit" );
         net->oil_temp[i] = node->getDoubleValue( "oil-temperature-degf" );
         net->oil_px[i] = node->getDoubleValue( "oil-pressure-psi" );
     }
@@ -205,7 +207,9 @@ void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
     net->elevator = node->getDoubleValue( "elevator-pos-norm" );
     net->elevator_trim_tab
         = node->getDoubleValue( "elevator-trim-tab-pos-norm" );
-    net->flaps = node->getDoubleValue( "flap-pos-norm" );
+    // FIXME: CLO 10/28/04 - This really should be separated out into 2 values
+    net->left_flap = node->getDoubleValue( "flap-pos-norm" );
+    net->right_flap = node->getDoubleValue( "flap-pos-norm" );
     net->left_aileron = node->getDoubleValue( "left-aileron-pos-norm" );
     net->right_aileron = node->getDoubleValue( "right-aileron-pos-norm" );
     net->rudder = node->getDoubleValue( "rudder-pos-norm" );
@@ -251,7 +255,9 @@ void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
             htonf(net->rpm[i]);
             htonf(net->fuel_flow[i]);
             htonf(net->egt[i]);
+            htonf(net->cht[i]);
             htonf(net->mp_osi[i]);
+            htonf(net->tit[i]);
             htonf(net->oil_temp[i]);
             htonf(net->oil_px[i]);
         }
@@ -276,7 +282,8 @@ void FGProps2NetFDM( FGNetFDM *net, bool net_byte_order ) {
 
         htonf(net->elevator);
         htonf(net->elevator_trim_tab);
-        htonf(net->flaps);
+        htonf(net->left_flap);
+        htonf(net->right_flap);
         htonf(net->left_aileron);
         htonf(net->right_aileron);
         htonf(net->rudder);
@@ -329,7 +336,9 @@ void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
             htonf(net->rpm[i]);
             htonf(net->fuel_flow[i]);
             htonf(net->egt[i]);
+            htonf(net->cht[i]);
             htonf(net->mp_osi[i]);
+            htonf(net->tit[i]);
             htonf(net->oil_temp[i]);
             htonf(net->oil_px[i]);
         }
@@ -353,7 +362,8 @@ void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
 
         htonf(net->elevator);
         htonf(net->elevator_trim_tab);
-        htonf(net->flaps);
+        htonf(net->left_flap);
+        htonf(net->right_flap);
         htonf(net->left_aileron);
         htonf(net->right_aileron);
         htonf(net->rudder);
@@ -424,7 +434,9 @@ void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
 	    node->setDoubleValue( "rpm", net->rpm[i] );
 	    node->setDoubleValue( "fuel-flow-gph", net->fuel_flow[i] );
 	    node->setDoubleValue( "egt-degf", net->egt[i] );
+	    node->setDoubleValue( "cht-degf", net->cht[i] );
 	    node->setDoubleValue( "mp-osi", net->mp_osi[i] );
+	    node->setDoubleValue( "tit", net->tit[i] );
 	    node->setDoubleValue( "oil-temperature-degf", net->oil_temp[i] );
 	    node->setDoubleValue( "oil-pressure-psi", net->oil_px[i] );		
 	}
@@ -457,7 +469,10 @@ void FGNetFDM2Props( FGNetFDM *net, bool net_byte_order ) {
         node->setDoubleValue("elevator-pos-norm", net->elevator);
         node->setDoubleValue("elevator-trim-tab-pos-norm",
                              net->elevator_trim_tab);
-        node->setDoubleValue("flap-pos-norm", net->flaps);
+	// FIXME: CLO 10/28/04 - This really should be separated out
+	// into 2 values
+        node->setDoubleValue("flap-pos-norm", net->left_flap);
+        node->setDoubleValue("flap-pos-norm", net->right_flap);
         node->setDoubleValue("left-aileron-pos-norm", net->left_aileron);
         node->setDoubleValue("right-aileron-pos-norm", net->right_aileron);
         node->setDoubleValue("rudder-pos-norm", net->rudder);
