@@ -2,7 +2,7 @@
 //
 // Written by Curtis Olson, started January 2002.
 //
-// Copyright (C) 2002  Curtis L. Olson - curt@flightgear.org
+// Copyright (C) 2002  Curtis L. Olson - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: native_gui.cxx,v 1.10 2003/07/25 20:10:09 curt Exp $
+// $Id: native_gui.cxx,v 1.15 2004/12/30 20:48:54 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -30,7 +30,6 @@
 #include <simgear/io/iochannel.hxx>
 #include <simgear/timing/sg_time.hxx>
 
-#include <Cockpit/radiostack.hxx>
 #include <FDM/flight.hxx>
 #include <Time/tmp.hxx>
 #include <Main/fg_props.hxx>
@@ -121,6 +120,22 @@ bool FGNativeGUI::open() {
 
 
 void FGProps2NetGUI( FGNetGUI *net ) {
+    static SGPropertyNode *nav_freq
+	= fgGetNode("/instrumentation/nav/frequencies/selected-mhz", true);
+    static SGPropertyNode *nav_target_radial
+	= fgGetNode("/instrumentation/nav/radials/target-radial-deg", true);
+    static SGPropertyNode *nav_inrange
+	= fgGetNode("/instrumentation/nav/in-range", true);
+    static SGPropertyNode *nav_loc
+	= fgGetNode("/instrumentation/nav/nav-loc", true);
+    static SGPropertyNode *nav_gs_dist_signed
+	= fgGetNode("/instrumentation/nav/gs-distance", true);
+    static SGPropertyNode *nav_loc_dist
+	= fgGetNode("/instrumentation/nav/nav-distance", true);
+    static SGPropertyNode *nav_reciprocal_radial
+	= fgGetNode("/instrumentation/nav/radials/reciprocal-radial-deg", true);
+    static SGPropertyNode *nav_gs_deflection
+	= fgGetNode("/instrumentation/nav/gs-needle-deflection", true);
     int i;
 
     // Version sanity checking
@@ -151,24 +166,25 @@ void FGProps2NetGUI( FGNetGUI *net ) {
     net->ground_elev = globals->get_scenery()->get_cur_elev();
 
     // Approach
-    net->tuned_freq = current_radiostack->get_navcom1()->get_nav_freq();
-    net->nav_radial = current_radiostack->get_navcom1()->get_nav_target_radial();
-    net->in_range = current_radiostack->get_navcom1()->get_nav_inrange();
+    net->tuned_freq = nav_freq->getDoubleValue();
+    net->nav_radial = nav_target_radial->getDoubleValue();
+    net->in_range = nav_inrange->getBoolValue();
 
-    if ( current_radiostack->get_navcom1()->get_nav_loc() ) {
+    if ( nav_loc->getBoolValue() ) {
         // is an ILS
         net->dist_nm
-            = current_radiostack->get_navcom1()->get_nav_gs_dist_signed()
+            = nav_gs_dist_signed->getDoubleValue()
               * SG_METER_TO_NM;
     } else {
         // is a VOR
-        net->dist_nm = current_radiostack->get_navcom1()->get_nav_loc_dist()
+        net->dist_nm = nav_loc_dist->getDoubleValue()
             * SG_METER_TO_NM;
     }
 
     net->course_deviation_deg
-        = current_radiostack->get_navcom1()->get_nav_reciprocal_radial()
-        - current_radiostack->get_navcom1()->get_nav_target_radial();
+        = nav_reciprocal_radial->getDoubleValue()
+        - nav_target_radial->getDoubleValue();
+
     if ( net->course_deviation_deg < -1000.0 
          || net->course_deviation_deg > 1000.0 )
     {
@@ -187,10 +203,10 @@ void FGProps2NetGUI( FGNetGUI *net ) {
                 ? -net->course_deviation_deg - 180.0
                 : -net->course_deviation_deg + 180.0 );
 
-    if ( current_radiostack->get_navcom1()->get_nav_loc() ) {
+    if ( nav_loc->getBoolValue() ) {
         // is an ILS
         net->gs_deviation_deg
-            = current_radiostack->get_navcom1()->get_nav_gs_deflection()
+            = nav_gs_deflection->getDoubleValue()
             / 5.0;
     } else {
         // is an ILS
@@ -290,13 +306,13 @@ void FGNetGUI2Props( FGNetGUI *net ) {
         globals->get_scenery()->set_cur_elev( net->ground_elev );
 
         // Approach
-        fgSetDouble( "/radios/nav[0]/frequencies/selected-mhz",
+        fgSetDouble( "/instrumentation/nav[0]/frequencies/selected-mhz",
                      net->tuned_freq );
-        fgSetBool( "/radios/nav[0]/in-range", net->in_range );
-        fgSetDouble( "/radios/dme/distance-nm", net->dist_nm );
-        fgSetDouble( "/radios/nav[0]/heading-needle-deflection",
+        fgSetBool( "/instrumentation/nav[0]/in-range", net->in_range );
+        fgSetDouble( "/instrumentation/dme/distance-nm", net->dist_nm );
+        fgSetDouble( "/instrumentation/nav[0]/heading-needle-deflection",
                      net->course_deviation_deg );
-        fgSetDouble( "/radios/nav[0]/gs-needle-deflection",
+        fgSetDouble( "/instrumentation/nav[0]/gs-needle-deflection",
                      net->gs_deviation_deg );
     } else {
 	SG_LOG( SG_IO, SG_ALERT,
