@@ -2,7 +2,7 @@
 //
 // Written by Curtis Olson, started Juley 2003.
 //
-// Copyright (C) 2003  Curtis L. Olson  - curt@flightgear.org
+// Copyright (C) 2003  Curtis L. Olson  - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: replay.cxx,v 1.14 2004/04/02 16:20:17 curt Exp $
+// $Id: replay.cxx,v 1.17 2005/01/05 03:43:05 curt Exp $
 
 
 #include <simgear/constants.h>
@@ -268,7 +268,9 @@ static FGReplayData interpolate( double time, FGReplayData f1, FGReplayData f2 )
         result.fdm.fuel_flow[i]
             = weight( fdm1.fuel_flow[i], fdm2.fuel_flow[i], ratio );
         result.fdm.egt[i] = weight( fdm1.egt[i], fdm2.egt[i], ratio );
+        result.fdm.cht[i] = weight( fdm1.cht[i], fdm2.cht[i], ratio );
         result.fdm.mp_osi[i] = weight( fdm1.mp_osi[i], fdm2.mp_osi[i], ratio );
+        result.fdm.tit[i] = weight( fdm1.tit[i], fdm2.tit[i], ratio );
         result.fdm.oil_temp[i]
             = weight( fdm1.oil_temp[i], fdm2.oil_temp[i], ratio );
         result.fdm.oil_px[i] = weight( fdm1.oil_px[i], fdm2.oil_px[i], ratio );
@@ -299,7 +301,8 @@ static FGReplayData interpolate( double time, FGReplayData f1, FGReplayData f2 )
 
     // Control surface positions (normalized values)
     result.fdm.elevator = weight( fdm1.elevator, fdm2.elevator, ratio );
-    result.fdm.flaps = weight( fdm1.flaps, fdm2.flaps, ratio );
+    result.fdm.left_flap = weight( fdm1.left_flap, fdm2.left_flap, ratio );
+    result.fdm.right_flap = weight( fdm1.right_flap, fdm2.right_flap, ratio );
     result.fdm.left_aileron
         = weight( fdm1.left_aileron, fdm2.left_aileron, ratio );
     result.fdm.right_aileron
