@@ -2,7 +2,7 @@
 //
 // Written by Curtis Olson, started May 1998.
 //
-// Copyright (C) 1998 - 2001  Curtis L. Olson  - curt@flightgear.org
+// Copyright (C) 1998 - 2001  Curtis L. Olson  - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: tileentry.cxx,v 1.40 2004/10/10 19:19:23 ehofman Exp $
+// $Id: tileentry.cxx,v 1.43 2004/12/08 14:45:47 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -702,6 +702,10 @@ FGTileEntry::load( const string_list &path_list, bool is_base )
             while ( ! in.eof() ) {
                 in >> token;
 
+                if ( token[0] == '#' ) {
+                   in >> ::skipeol;
+                   continue;
+                }
                                 // Load only once (first found)
                 if ( token == "OBJECT_BASE" ) {
                     in >> name >> ::skipws;
@@ -1006,7 +1010,9 @@ FGTileEntry::add_ssg_nodes( ssgBranch *terrain_branch,
     // bump up the ref count so we can remove this later without
     // having ssg try to free the memory.
 #if PLIB_VERSION > 183
-    makeDList( terra_transform );
+    if ( fgGetBool( "/sim/rendering/use-display-list", true ) ) {
+        makeDList( terra_transform );
+    }
 #endif
 
     terra_transform->ref();
