@@ -2,7 +2,7 @@
 //
 // Written by Curtis Olson, started January 1998.
 //
-// Copyright (C) 1997  Curtis L. Olson  - curt@infoplane.com
+// Copyright (C) 1997  Curtis L. Olson  - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: tilemgr.cxx,v 1.41 2004/09/15 15:52:05 curt Exp $
+// $Id: tilemgr.cxx,v 1.43 2004/11/22 10:10:33 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -515,6 +515,9 @@ void FGTileMgr::prep_ssg_nodes( SGLocation *location, float vis ) {
     // selector and transform
 
     Point3D center = location->get_tile_center();
+    if (center == Point3D(0.0))
+      return;
+    current_center = center;
     float *up = location->get_world_up();
 
     FGTileEntry *e;
