@@ -3,7 +3,7 @@
 //
 // Written by Curtis Olson, started April 1998.
 //
-// Copyright (C) 1998  Curtis L. Olson  - curt@me.umn.edu
+// Copyright (C) 1998  Curtis L. Olson  - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,7 +19,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: light.cxx,v 1.43 2004/04/01 15:28:14 curt Exp $
+// $Id: light.cxx,v 1.45 2004/11/19 22:10:45 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -30,10 +30,10 @@
 #  include <windows.h>
 #endif
 
-#include <GL/gl.h>
-
 #include <simgear/compiler.h>
 
+#include SG_GL_H
+
 #ifdef SG_MATH_EXCEPTION_CLASH
 #  define exception c_exception
 #endif
