@@ -47,6 +47,7 @@
 #include <simgear/compiler.h>
 #include <simgear/math/polar3d.hxx>
 #include <simgear/math/sg_geodesy.hxx>
+#include <simgear/misc/sg_path.hxx>
 #include <simgear/props/props.hxx>
 #include <simgear/route/waypoint.hxx>
 #include <simgear/structure/subsystem_mgr.hxx>
@@ -89,6 +90,26 @@ void FGTrafficManager::update(double something)
     currAircraft++;
 }
 
+void FGTrafficManager::release(void *id)
+{
+  releaseList.push_back(id);
+}
+
+bool FGTrafficManager::isReleased(void *id)
+{
+  IdListIterator i = releaseList.begin();
+  while (i != releaseList.end())
+    {
+      if ((*i) == id)
+	{
+	  releaseList.erase(i);
+	  return true;
+	}
+      i++;
+    }
+  return false;
+}
+
 void  FGTrafficManager::startXML () {
   //cout << "Start XML" << endl;
 }
@@ -107,11 +128,11 @@ void  FGTrafficManager::startElement (const char * name, const XMLAttributes &at
   if (attval != 0)
       {
 	//cout << "including " << attval << endl;
-	string path = 
-	  globals->get_fg_root()   + 
-	  string("/Traffic/")      + 
-	  string(attval);
-	readXML(path, *this);
+	SGPath path = 
+	  globals->get_fg_root();
+	path.append("/Traffic/");
+	path.append(attval);
+	readXML(path.str(), *this);
       }
   //  cout << "  " << atts.getName(i) << '=' << atts.getValue(i) << endl; 
 }
