@@ -2,7 +2,7 @@
 //
 // Written by Curtis Olson, started November 2002.
 //
-// Copyright (C) 2002  Curtis L. Olson  - curt@flightgear.org
+// Copyright (C) 2002  Curtis L. Olson  - http://www.flightgear.org/~curt
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: terrasync.cxx,v 1.6 2004/06/05 18:46:36 curt Exp $
+// $Id: terrasync.cxx,v 1.8 2004/12/05 01:16:35 curt Exp $
 
 
 #include <stdlib.h>             // atoi() atof() abs() system()
@@ -38,7 +38,7 @@ SG_USING_STD(cout);
 SG_USING_STD(endl);
 
 static string server = "scenery.flightgear.org";
-static string source_module = "Scenery-0.9.5";
+static string source_module = "Scenery";
 static string source_base = server + (string)"::" + source_module;
 static string dest_base = "/dest/scenery/dir";
 
